@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Overlay;
-$Template::Overlay::VERSION = '1.08';
+$Template::Overlay::VERSION = '1.09';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -91,9 +91,14 @@ sub overlay {
 sub _resolve {
     my ( $self, $template, $file ) = @_;
 
-    $logger->info( 'processing [', $template, '] -> [', $file, ']' );
+    if ( -f $file ) {
+        $logger->debugf(
+            '[%s] already exists, deleting to ensure creation with proper permissions', $file );
+        unlink($file);
+    }
 
     my $mode = stat($template)->mode() & 07777;    ## no critic
+    $logger->infof( 'processing [%s] -> [%04o] [%s]', $template, $mode, $file );
     sysopen( my $handle, $file, O_CREAT | O_TRUNC | O_WRONLY, $mode )
         || croak("open $file failed: $!");
     eval {
@@ -120,7 +125,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
